"""MCP Vector Search - CLI-first semantic code search with MCP integration."""

__version__ = "0.12.7"
__build__ = "56"
__author__ = "Robert Matsuoka"
__email__ = "bobmatnyc@gmail.com"

from .core.exceptions import MCPVectorSearchError

__all__ = ["MCPVectorSearchError", "__version__", "__build__"]
